#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : demo
# @Time         : 2021/9/4 下午3:26
# @Author       : yuanjie
# @WeChat       : 313303303
# @Software     : PyCharm
# @Description  : 根据系统信息与聊天记录评价一个人
import re

from meutils.pipe import *

import xchat.itchat as itchat
from xchat.itchat.content import INCOME_MSG, TEXT, PICTURE, NOTE
from xchat.schemas.wechat.message import MessageType, QuoteMessage
from xchat.itchat.storage.messagequeue import Message
# from xchat.schemas.msg import Message as _Message, User

from xchat.schemas.wechat.message import Message as _Message


@decorator
def msg_filter(func, chatroom_regexp: Optional[str] = None, *msgs):
    """
        过滤群聊、私聊
    """
    msg = _Message(**obj_to_dict(msgs[0]))

    if (
            msg.CreateTime > time.time() - 5
            and (re.search(chatroom_regexp, msg.chatroom_name) if chatroom_regexp else True)

    ):
        return func(msg)


@itchat.msg_register([MessageType.TEXT, MessageType.ATTACHMENT], isGroupChat=True)  # 注册处理文本信息
@msg_filter
def reply(msg: Message):
    logger.debug(msg)
    _msg = msg
    msg = obj_to_dict(msg)
    # logger.debug(f"{msg}")
    # logger.debug(f"{User(**msg['User'])}")
    # logger.debug(f"UserUserUserUserUserUserUserUserUserUser")
    # user = msg.pop('User')

    msg = _Message(**msg)  # filter
    logger.debug(f"{msg}")

    group_name = msg.chatroom_name  # msg.User.NickName
    # msg.ToUserName 加密的群名
    logger.debug(f"群名: {group_name}")

    # msg.ToUserName， msg.ActualNickName群里机器人的name
    # msg.FromUserName 群id【除非机器人本身发信息，就是他自己的id】

    if (
            not hasattr(msg, 'CreateTime')
            or msg.CreateTime > time.time() - 10
            and "机器人调试" in group_name
    ):  # todo: 增加过滤函数
        logger.debug(f"[{type(msg)} => {msg.Type}]")

        ###############################################################

        from meutils.hooks.wechat import create_reply

        hook = create_reply(_msg, itchat_send=itchat.send)
        if hook: return

        ###############################################################
        logger.debug("测试发送")

        # itchat.send('@img@doc_watermark.jpg', toUserName=msg.chatroom_id)  # ToUserName
        # itchat.send('@img@doc_watermark.webp', toUserName=msg.chatroom_id)
        # itchat.send_image('doc_watermark.jpg', toUserName=msg.chatroom_id)
        # logger.debug('1')
        # itchat.send_image('doc_watermark.webp', toUserName=msg.chatroom_id)
        # logger.debug('2')




        # 使用上下文管理器自动处理文件的关闭和删除
        with tempfile.NamedTemporaryFile(mode='wb+', suffix='.txt') as temp: # suffix
            temp.write(b"This is a temporary file.")
            temp.seek(0)

            itchat.send(f'@fil@{temp.name}', toUserName=msg.chatroom_id)  # ToUserName

        # itchat.send_image(open('doc_watermark.jpg', 'rb'), toUserName=msg.chatroom_id)

        # itchat.send('@img@1.webp', toUserName=msg.chatroom_id)  # ToUserName
        # itchat.send('@img@1.webp', toUserName=msg.chatroom_id)  # ToUserName
        # itchat.send('@msg@1.webp', toUserName=msg.chatroom_id)  # ToUserName
        #
        # itchat.send('@vid@vidu.mp4', toUserName=msg.chatroom_id)  # ToUserName

        # itchat.send(f"FromUserName: {msg.FromUserName}", toUserName=msg.chatroom_id)  # msg.FromUserName
        # itchat.send('@fil@test.ipynb', toUserName=msg.chatroom_id)  # ToUserName
        # itchat.send('@fil@test.ipynb', toUserName=msg.ToUserName)  # ToUserName
        # itchat.send('@fil@test.ipynb', toUserName=msg.chatroom_id)  # ToUserName

        # itchat.send_image

        # itchat.send('@vid@vidu.mp4', toUserName=msg.chatroom_id)  # ToUserName

        # itchat.send('@img@1.webp', toUserName=msg.chatroom_id)  # ToUserName
        # itchat.send('@img@1.png', toUserName=msg.chatroom_id)  # ToUserName
        # itchat.send('@img@doc_watermark.jpg', toUserName=msg.chatroom_id)  # ToUserName

        # itchat.send('@fil@vidu.mp4', toUserName=msg.chatroom_id)  # ToUserName
        # itchat.send('@fil@doc_watermark.jpg', toUserName=msg.chatroom_id)  # ToUserName

        # itchat.send('@vid@x.mp3', toUserName=msg.chatroom_id)  # ToUserName
        # itchat.send('@img@x.mp3', toUserName=msg.chatroom_id)  # ToUserName

        # itchat.send(
        #     f'@fil@{"/Users/betterme/PycharmProjects/AI/aizoo/.idea/misc.xml"}',
        #     toUserName=msg.chatroom_id)  # ToUserName


# ['@fil@', '@img@', '@msg@', '@vid@']

# @itchat.msg_register(MessageType.SHARING)  # 注册处理文本信息
# def reply(msg):
#     print(str(msg))
#     print(requests.get(msg.Url).content)
#
#
# @itchat.msg_register([MessageType.TEXT, MessageType.ATTACHMENT], isGroupChat=True)
# def handler_group_msg(msg):
#     if not hasattr(msg, 'CreateTime') or msg.CreateTime > time.time() - 10:  # todo: 增加过滤函数
#         # ActualNickName
#         WECHAT_DATA = os.getenv('WECHAT_DATA', 'wechat_data').rstrip('/')
#         p = Path(f'{WECHAT_DATA}/{msg.User.NickName}')  # 用户【非机器人】todo: 常用信息封装
#         if msg.ToUserName == msg.User.UserName: p /= '机器返回'
#         p.mkdir(parents=True, exist_ok=True)
#         if msg["FileName"]:
#             msg.download(p / msg["FileName"])  # ['Picture', 'Recording', 'Attachment', 'Video']
#             # background_tasks
#
#         if msg.User.NickName == 'Wechat测试' and msg.IsAt:  # 被@回答问题
#             logger.debug(f"[{type(msg)} => {msg.type}]")
#             logger.debug(msg.keys())
#
#             print(str(msg))
#             # 'Text': '「Bettermeeeeeee：[文件]东北证券AI架构.pptx」\n- - - - - - - - - - - - - - -\n@Bettermeeeeeee\u2005qqqq'
#             logger.debug(msg.User)
#
#             msg.User.send_msg(f'@{msg.ActualNickName}\u2005「机器人回答1」')
#             # msg.User.send_msg(f'@{msg.ActualNickName} 「机器人回答2」')
#             # msg.User.send_msg(f'@{msg.ActualNickName}「机器人回答3」')


# 'ActualNickName', 'IsAt', 'ActualUserName'
# 'ActualNickName', 'IsAt', 'ActualUserName',

# import wxpy

# mp_username = itchat.search_mps(name='Python之禅')[0]['UserName']

if __name__ == '__main__':
    itchat.auto_login(hotReload=os.getenv('WECHAT_RELOAD'))  # hotReload=True表示短时间关闭程序后可重连
    # print(itchat.search_mps('Python之禅'))
    # mp_username = itchat.search_mps(name='Python之禅')[0]['UserName']

    # 'FromUserName': '@839adce9c446b9aa6284371d2a03ea74', 'ToUserName': '@65b692db46f1365b376891a856853124544b18b95e52e9e18985a466fd1e34d0'
    # print(itchat.search_friends(userName="@aa8e769e75daa860fd7bebf0a7c3af32bc4b731f920ef02a3830328ce936c492"))
    # itchat.run()

    itchat.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : dify_types
# @Time         : 2024/8/30 10:49
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

BASE_URL = "https://flow.chatfire.cn/v1"


class ChatCompletionResponse(BaseModel):
    pass


class ChatCompletionChunkResponse(BaseModel):
    event: str = "message"
    id: Optional[str] = None
    task_id: Optional[str] = None
    message_id: Optional[str] = None
    conversation_id: Optional[str] = None
    answer: str = ""
    created_at: int = Field(default_factory=lambda: int(time.time()))

    # position: int
    # thought: str
    # observation: str
    # tool: str
    # tool_input: dict
    # message_files: List[str]


if __name__ == '__main__':
    chunk = """data: {"event": "message", "task_id": "900bbd43-dc0b-4383-a372-aa6e6c414227", "id": "663c5084-a254-4040-8ad3-51f2a3c1a77c", "answer": "Hi", "created_at": 1705398420}\n\n"""
    _ = ChatCompletionChunkResponse.model_validate_json(chunk.strip('data:'))
    print(_)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2024/10/21 20:17
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://platform.minimaxi.com/document/video_generation?key=66d1439376e52fcee2853049
# https://useapi.net/docs/start-here/setup-minimax
# token 过期时间一个月: 看下free hailuo
# https://jwt.io/
import asyncio

# todo: check token 跳过错误 敏感


from meutils.pipe import *
from meutils.hash_utils import md5
from meutils.io.files_utils import to_bytes, to_url, to_image
from meutils.schemas.hailuo_types import BASE_URL_ABROAD as BASE_URL

from meutils.decorators.retry import retrying, IgnoredRetryException

from meutils.apis.hailuoai.yy import get_yy
from meutils.apis.hailuoai.utils import PARAMS as params, get_access_token, upload

from meutils.schemas.image_types import ImageRequest, ImagesResponse
from meutils.schemas.video_types import SoraVideoRequest, Video

MODELS_MAPPING = {
    "async/nano-banana-pro": "nano-banana2"
}


# @rcache(ttl=7 * 24 * 3600, skip_cache_func=skip_cache_func)

async def generate(request: ImageRequest, api_key: Optional[str] = None, is_async: bool = False):
    refresh_token = api_key or os.getenv("HAILUOAI_API_KEY")
    token = await get_access_token(refresh_token)

    request.model = MODELS_MAPPING.get(request.model, request.model)

    payload = {
        "quantity": request.n,
        "parameter": {
            "modelID": request.model,
            "desc": request.prompt,
            "fileList": [],
            "useOriginPrompt": True if "--enhance" not in request.prompt else False,  # enhance-prompt
            "aspectRatio": request.aspect_ratio or "Auto",
            "resolution": (request.resolution or "1K").title()
        }
    }

    if request.model.startswith('gpt'):
        if payload['parameter']['aspectRatio'] not in {"Auto", "1:1", "2:3", "3:2"}:
            payload['parameter']['aspectRatio'] = "Auto"

    elif request.model.startswith('image'):
        payload['parameter']["resolution"] = ""

    elif request.model.startswith('nano-banana'):
        if payload['parameter']['aspectRatio'] not in {
            "Auto", '1:1', '21:9', '16:9', '2:3', '3:4', '5:4', '4:5', '4:3', '9:16', '3:2'}:
            payload['parameter']['aspectRatio'] = "Auto"
            payload['parameter']['desc'] += f" --size {request.aspect_ratio}"

    if request.image:
        payload['parameter']['fileList'] = [
            {
                # "url": url,
                # "url": await to_url(url, filename='xx.jpeg'), # 不是真转换

                "url": await to_image(url, mini_aspect_ratio="2:5"),  # 重置为 jpg

                # "id": "469899357624119304",
                # "name": "image.png",
                # "type": "png",
                # "frameType": 3
            }
            for url in request.image_urls
        ]

    logger.debug(bjson(payload))
    # return
    path = "/v2/api/multimodal/generate/image"
    headers = {
        'Content-Type': 'application/json',
        'token': token,
        'yy': get_yy(payload, params, path),
    }

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post(path, params=params, content=json.dumps(payload))
        response.raise_for_status()

        data = response.json()

        logger.debug(bjson(data))

        # 异步任务
        if is_async:
            if task_id := (data.get('data') or {}).get('task', {}).get('batchID'):  # 图片取 batchID
                return Video(id=task_id, status=data)
            else:
                return Video(status='failed', error=data.get("statusInfo"))

        image_response = None
        if task_id := (data.get('data') or {}).get('task', {}).get('batchID'):
            logger.debug(f"TASK_ID: {task_id}")

            for _ in range(60):
                await asyncio.sleep(5) if _ else await asyncio.sleep(16)

                if image_response := await get_task(task_id, token):
                    if image_response.data and len(image_response.data) == request.n:
                        return image_response

        if image_response and image_response.data:
            return image_response
        else:
            raise Exception(f"invalid image null: {task_id} \n\n {request.prompt[:1000]}")


async def get_task(task_id: str, token: str):
    batch_id = task_id

    payload = {
        "batchInfoList": [
            {
                "batchID": batch_id,
                "batchType": 1
            }
        ],
        "type": 1
    }

    path = "/v4/api/multimodal/video/processing"
    headers = {
        'Content-Type': 'application/json',
        'token': token,
        'yy': get_yy(payload, params, url=path),
    }

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post(path, params=params, content=json.dumps(payload))
        response.raise_for_status()
        data = response.json()
        logger.debug(bjson(data))

        # if any(i in str(data) for i in {"内容生成失败", "请求异常"}):
        #     raise Exception(f"invalid image: {task_id} \n\n {request.prompt[:1000]}")

        if batchs := data['data']['batchVideos']:
            for batch in batchs:
                if batch["batchID"] == task_id:
                    _ = batch["assets"][0]
                    logger.debug(bjson(_))

                    if url := _.get("downloadURL"):
                        data = [{"url": url}]
                        return ImagesResponse(data=data, metadata=payload)

            return ImagesResponse(metadata=payload)
        # if batchs := data['data']['batchVideos']:
        #     if batchs and (assets := batchs[0]['assets']):  # 取第一个
        #
        #         data = [
        #             {"url": image.get("downloadURL")}
        #             for image in assets if image.get("downloadURL")
        #         ]
        #
        #         return ImagesResponse(data=data, metadata=payload)


# todo: 任务状态接口
if __name__ == '__main__':
    token = None
    token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NzIyODE1NzcsInVzZXIiOnsiaWQiOiI0NDQyMjk2MDAzMzA0OTgwNTUiLCJuYW1lIjoibWZ1aiBiamhuIiwiYXZhdGFyIjoiIiwiZGV2aWNlSUQiOiIzMzkxMTQ5Mjg4NjU1Mjk4NjQiLCJpc0Fub255bW91cyI6ZmFsc2V9fQ.__NDyZQQqyYb7TLrumo944EfuCmrbzYngQloNBK4CmM"
    # token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NzIzNTA5NjUsInVzZXIiOnsiaWQiOiI0Njk4ODIxOTY3NDM1Mjg0NDkiLCJuYW1lIjoiYWZzbCBkcnF2IiwiYXZhdGFyIjoiIiwiZGV2aWNlSUQiOiIzMTE2NzAxODUwMDg0ODg0NTIiLCJpc0Fub255bW91cyI6ZmFsc2V9fQ.3pO0O36-um2fQs0ML0eHwpi0D7rV5yjmnjcpuiZcNKw"
    token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NzIzNTA5NjUsInVzZXIiOnsiaWQiOiI0Njk4ODIxOTY3NDM1Mjg0NDkiLCJuYW1lIjoiYWZzbCBkcnF2IiwiYXZhdGFyIjoiIiwiZGV2aWNlSUQiOiIzMTE2NzAxODUwMDg0ODg0NTIiLCJpc0Fub255bW91cyI6ZmFsc2V9fQ.3pO0O36-um2fQs0ML0eHwpi0D7rV5yjmnjcpuiZcNKw"
    token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NzM0NzAyOTYsInVzZXIiOnsiaWQiOiI0Njk5MzQwNDI3MzI0MDA2NDciLCJuYW1lIjoiZm1vZyB0cm9nIiwiYXZhdGFyIjoiIiwiZGV2aWNlSUQiOiIzMTExNjM2MjIzODg4NTA2OTAiLCJpc0Fub255bW91cyI6ZmFsc2V9fQ.DLSoWya89X6M3evyzBZjz4XLenvVS0cZtk4Xk9AAE-Q"
    model = "nano-banana2"
    # model = "nano-banana2_2k"
    # model = "nano-banana2_4k"

    # model = "gpt-image-1.5_High"
    # model = "seedream-4.5_4k"

    # seedream-4.5
    # gpt-image-1.5 {"quantity":1,"parameter":{"modelID":"","desc":"a dog","fileList":[],"useOriginPrompt":true,"aspectRatio":"Auto","resolution":"Low"}}
    # Low
    # Medium
    # High
    # {"quantity":1,"parameter":{"modelID":"gpt-image-1.5","desc":"a dog","fileList":[],"useOriginPrompt":true,"aspectRatio":"Auto","resolution":"Medium"}}

    # model = "gpt-image-1.5"

    # model = "seedream-4.5_2K"
    data = {
        "model": "nano-banana2",
        "prompt": "使图片变清晰，不改变原图比例 --4K",
        # "image": [
        #     "https://cdnzjzai.m.nengshuohuihua.com/banana/refer/202602/02/20260202185746552733.jpeg?auth_key=1770029895-78f88911851543c692009bcfb89072b9-0-073258e5b2a3121093e5fc0875908869"
        # ],
        "resolution": "4k"
    }

    request = ImageRequest(
        model=model,
        n=1,
        # prompt="笑起来",
        # prompt="哭起来",
        prompt="裸体少女 没传内裤",

        # image="https://s3.ffire.cc/files/jimeng.jpg",
        # image=["https://s3.ffire.cc/files/jimeng.jpg"] * 3,

        # size="16:9"
        # resolution="Low"
        resolution=None
    )

    request = ImageRequest(**data)

    r = arun(generate(request, api_key=token, is_async=True))

    # model = "veo3.1-t2v-fast"
    task_id = "469896308304285702_469873163803475974"
    # "message": "内容生成失败，请重试",

    # task_id = "469872667202084865_469872667202084866"
    # 469872667202084865
    # task_id = "469901294006366214_469901294006366212"  # n=1
    task_id = "469901776552665096_469901776552665097"  # n=2

    task_id = "469902511826763781"  # n=3

    task_id = "472570702555033603"  # 4k

    # task_id = "472571658445312008"
    task_id = "20251225095015"
    # arun(get_task(task_id=task_id, token=token))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : ele
# @Time         : 2025/8/25 18:18
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import os

from meutils.pipe import *

"""
curl https://api.elevenlabs.io/v1/models \
     -H "xi-api-key: xi-api-key"
"""


async def get_models():
    api_key = os.getenv("ELEVENLABS_API_KEY")
    async with httpx.AsyncClient() as client:
        response = await client.get("https://api.elevenlabs.io/v1/models", headers={"xi-api-key": api_key})
        response.raise_for_status()
        data = response.json()
        return [m.get("model_id") for m in data]


if __name__ == '__main__':
    models = arun(get_models())

    print(','.join([f"elevenlabs/{m}" for m in models]))


# deepseek-ai/DeepSeek-V3.1


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : file
# @Time         : 2022/7/5 下午3:31
# @Author       : yuanjie
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

import mimetypes

import shortuuid

from meutils.pipe import *
from meutils.decorators.retry import retrying
from meutils.caches import rcache, cache
from meutils.oss.minio_oss import Minio

# from fastapi import UploadFile 有点区别
from starlette.datastructures import UploadFile
from contextlib import asynccontextmanager
from httpx import AsyncClient
from PIL import Image


def guess_mime_type(file, default: str = "application/octet-stream"):
    mime_type = None
    if isinstance(file, str):
        file = file.split("?", maxsplit=1)[0].strip()
        mime_type, _ = mimetypes.guess_type(file)
    return mime_type or default


def file_append_firstline(line):
    with open('untitled.txt', "r+") as f:
        old = f.read()

        f.seek(0)
        f.write(line)
        f.write(old)


def base64_to_bytes(base64_image_string):
    """
    # 将字节数据写入图片文件
    image_data = base64_to_bytes(...)
    with open(filename, 'wb') as file:
        file.write(image_data)
    """
    return base64.b64decode(base64_image_string.split(",", 1)[-1])


async def to_bytes(
        file: Union[UploadFile, str, bytes],
        headers: Optional[dict] = None
):
    """

    :param file: 文件对象、路径、base64、url
    :param headers: httpx

    :return: todo: bytes、filepath、io.BytesIO
    """
    # assert file

    if isinstance(file, list):
        tasks = [to_bytes(_, headers) for _ in file]
        file_bytes_list = await asyncio.gather(*tasks)
        return file_bytes_list

    if isinstance(file, bytes):
        logger.debug(f"FileType: BYTES")

        return file

    elif isinstance(file, str):
        if file.startswith('http'):
            logger.debug(f"FileType: HTTP")

            async with AsyncClient(
                    headers=headers or {},
                    timeout=120,
                    verify=False
            ) as cilent:  # todo: 缓存 根据大小 判断有效链接  todo 无效链接 下载超时 等等
                resp = await cilent.get(file)
                file_bytes = resp.content

        elif file.startswith('data:') and ";base64," in file or len(file) > 1024:
            logger.debug(f"FileType: BASE64")

            file_bytes = base64_to_bytes(file)

        elif Path(file).is_file():  # file
            logger.debug(f"FileType: PATH")

            file_bytes = Path(file).read_bytes()

        else:
            raise Exception(f"FileType: MAY BASE64 or NOT EXIST")

        return file_bytes

    elif isinstance(file, UploadFile):
        file_bytes = await file.read()
        return file_bytes


@asynccontextmanager
async def to_tempfile(file: Union[UploadFile, str]):
    """

    :param file: 文件对象、路径、base64、url
    :return: todo: bytes、filepath、io.BytesIO
    """
    file_bytes = await to_bytes(file)

    with tempfile.NamedTemporaryFile(mode='wb+') as temp:
        temp.write(file_bytes)
        temp.seek(0)

        logger.debug(temp.name)

        yield temp.name


@retrying()
async def to_url_fal(
        file: Union[str, bytes, List],
        filename: Optional[str] = None,
        headers: Optional[dict] = None,
        content_type: str = "application/octet-stream",
):
    """对象存储 todo: minio"""
    if isinstance(file, list):
        tasks = [to_url_fal(_, filename, headers, content_type) for _ in file]
        urls = await asyncio.gather(*tasks)
        return urls

    if not file: return

    if isinstance(file, str) and file.startswith("http"):  # 转存： todo: base64
        content_type = mimetypes.guess_type(file)[0] or content_type

    file = await to_bytes(file, headers=headers)
    content_type = (
            mimetypes.guess_type(filename or '')[0]
            or mimetypes.guess_type(f"x.{content_type}")[0]  # format: image/png
            or content_type
    )

    import fal_client

    url = await fal_client.upload_async(data=file, content_type=content_type, file_name=filename)
    return url


async def to_url(
        file: Union[str, bytes, List],
        filename: Optional[str] = None,
        headers: Optional[dict] = None,

        content_type: Optional[str] = None,
        mime_type: Optional[str] = None,

):  # 传入 url 是否 转存
    if not file: return

    content_type = content_type or mime_type

    if isinstance(file, list):
        tasks = [to_url(_, f"{shortuuid.random()}_{filename}", headers, content_type=content_type) for _ in file]
        urls = await asyncio.gather(*tasks)
        return urls

    file = await to_bytes(file, headers=headers)
    file_url = await Minio().upload(file, filename, content_type=content_type)
    return file_url


async def to_base64(file: Union[UploadFile, str, bytes, list], content_type: Optional[str] = None):
    if isinstance(file, list):
        tasks = [to_base64(_, content_type) for _ in file]
        return await asyncio.gather(*tasks)

    if not file: return

    # logger.debug(file)await to_base64(request.input_reference)
    _ = base64.b64encode(await to_bytes(file)).decode('utf-8')

    # if content_type := content_type or mimetypes.guess_type(file)[0]:  # "image/png"
    if content_type:  # "image/png"
        _ = f"data:{content_type};base64,{_}"

    return _


def base64_to_file(base64_image_string, filename):
    image_data = base64_to_bytes(base64_image_string)
    with open(filename, 'wb') as file:
        file.write(image_data)


def file_to_base64(file):
    _ = base64.b64encode(Path(file).read_bytes()).decode('utf-8')
    content_type = mimetypes.guess_type(file)[0] or "data:image/jpeg"

    return f"data:{content_type},{_}"


async def to_file(file: Union[UploadFile, str, bytes], filename: Optional[str] = None):
    file = await to_bytes(file)
    if not filename:  # 临时文件
        with tempfile.NamedTemporaryFile(mode='wb+', delete=False) as temp:
            temp.write(file)
            temp.seek(0)
            return temp.name
    else:
        Path(filename).write_bytes(file)
        return Path(filename).resolve()


async def markdown_base64_to_url(text, pattern=r'!\[.*?\]\((.*?)\)'):
    """
    :param text:
    :param pattern:
        pattern=r'!\[.*?\]\((data:image/.*?)\)'
    :return:
    """
    base64_strings = re.findall(pattern, text)

    # logger.debug(text)
    # logger.debug(base64_strings)

    tasks = [to_url(base64_string, filename=f"{shortuuid.random()}.png") for base64_string in base64_strings]
    urls = await asyncio.gather(*tasks)

    for base64_string, url in zip(base64_strings, urls):
        text = text.replace(base64_string, url)
    return text


async def get_file_duration(filename: str = ".mp4", url: Optional[str] = None, content: Optional[bytes] = None,
                            headers: Optional[dict] = None):
    # Path(url.split('?')[0]).name
    headers = {
        "Range": "bytes=0-8191"
    }
    async with httpx.AsyncClient(timeout=200, follow_redirects=True) as client:
        for i in range(2):
            if url:
                response = await client.get(url=url, headers=headers)
                response.raise_for_status()

                content = response.content
            elif content is None:
                raise ValueError("url or content is required")

            from tinytag import TinyTag

            tag = TinyTag.get(filename=filename, file_obj=io.BytesIO(content), ignore_errors=False)

            logger.debug(f"duration: {tag.duration}")
            if tag.duration and tag.duration > 0.5:
                break
            else:
                headers = None

        return int(np.ceil(tag.duration or 10))


async def to_png(image: Union[bytes, List[bytes], str, List[str]], response_format: str = 'bytes'):
    """
    将 WebP 二进制数据无损转换为 PNG 二进制数据
    """
    if isinstance(image, list):
        tasks = [to_png(_, response_format) for _ in image]
        return await asyncio.gather(*tasks)

    if isinstance(image, str):
        image = await to_bytes(image)
        if not image:
            raise Exception(f"invalid image: {image}")

    with Image.open(io.BytesIO(image)) as im:
        out = io.BytesIO()
        im.save(out, format="PNG")  # 无损

        if response_format != "bytes":
            return await to_base64(out.getvalue(), content_type="image/png")

        return out.getvalue()


async def to_image(
        image: Union[bytes, List[bytes], str, List[str]],
        to_image_format: str = 'JPEG',  # PNG JPEG
        response_format: Literal["bytes", "base64", "url"] = "url",
        mini_aspect_ratio: Optional[str] = None
):
    """
    将 WebP 二进制数据无损转换为 PNG 二进制数据
    """
    logger.debug(image)

    if isinstance(image, list):
        tasks = [to_image(_, to_image_format, response_format) for _ in image]
        return await asyncio.gather(*tasks)

    if isinstance(image, str):
        # if guess_mime_type(image) == to_image_format.lower():  # 无需转换
        #     return image

        # logger.debug(image)

        image = await to_bytes(image)
        if not image:
            raise Exception(f"invalid image: {image}")

    with Image.open(io.BytesIO(image)) as img:
        out = io.BytesIO()
        # if img.mode == 'RGBA':
        #     logger.debug(img.mode)
        #     # 创建白色背景（或任何你想要的背景色）
        #     background = Image.new('RGB', img.size, (255, 255, 255))
        #     # 将 RGBA 图像粘贴到背景上，使用 Alpha 通道作为掩码
        #     background.paste(img, mask=img.split()[-1])
        #     img = background
        # elif img.mode != 'RGB':
        #     img = img.convert('RGB')

        img = img.convert('RGB')
        img.save(out, format=to_image_format.upper())

        image_bytes = out.getvalue()

        if mini_aspect_ratio:
            w, h = map(int, mini_aspect_ratio.split(':'))
            if not (min(w / h, h / w) < img.width / img.height < max(w / h, h / w)):
                logger.debug(f"resize: {mini_aspect_ratio}")
                target_ratio = min(w / h, h / w) + 0.01  # mini_aspect_ratio
                image_bytes = await image_resize(image_bytes, target_ratio=target_ratio, response_format="bytes")

        logger.debug(f"response_format: {response_format}")

        if response_format == "bytes":
            return image_bytes

        elif response_format == "url":
            return await to_url(image_bytes, filename=f"{shortuuid.random()}.{to_image_format.lower()}")

        else:
            return await to_base64(image_bytes, content_type=f"image/{to_image_format.lower()}")


async def do_file_data(
        file_or_str_list: Union[str, List[str], UploadFile, List[UploadFile]],
        input_reference_format: Optional[str] = None,
        content_type: Optional[str] = None,

        # todo 图片格式
):
    file = file_or_str_list

    if isinstance(file, list):
        tasks = [do_file_data(_, input_reference_format, content_type) for _ in file]
        return await asyncio.gather(*tasks)

    # 针对单文件
    if isinstance(file, str):  # url1;url2
        if ';' in file:
            return file.split(';')
        elif '|' in file:
            return file.split('|')

        return file

    elif isinstance(file, UploadFile):
        if not file.filename: return None

        content_type = content_type or file.content_type
        if input_reference_format in {"base64", "b64"}:
            file = await to_base64(await file.read(), content_type=content_type)

        elif input_reference_format == "oss":  # to url todo海外服务器
            file = await to_url(await file.read(), content_type=content_type)  # todo: 图片类型变换

        else:  # fal url
            file = await to_url_fal(await file.read(), content_type=content_type)

    return file  # 要返回 list?


async def image_resize(image: Union[bytes, str], target_ratio: Union[float, str], response_format,
                       fill_color=(0, 0, 0)):
    """
    将图片缩放到目标比例，保持完整内容，不足部分填充背景色

    output_path

    :param target_ratio: 目标宽高比 (width/height)，如 16/9
    """
    w = h = 1
    if isinstance(target_ratio, str):

        if 'x' in target_ratio:
            w, h = map(int, target_ratio.split('x'))
        elif ':' in target_ratio:
            w, h = map(int, target_ratio.split(':'))

        target_ratio = w / h

    _ = await to_bytes(image)
    img = Image.open(io.BytesIO(_))

    img_ratio = img.width / img.height

    # 计算缩放后的尺寸
    if img_ratio > target_ratio:
        # 原图更宽，以宽度为基准
        new_width = img.width
        new_height = int(img.width / target_ratio)
    else:
        # 原图更高或正好，以高度为基准
        new_height = img.height
        new_width = int(img.height * target_ratio)

    if w > 32:
        new_width, new_height = w, h

    # 创建目标尺寸画布并居中粘贴
    result = Image.new('RGB', (new_width, new_height), fill_color)

    offset_x = (new_width - img.width) // 2
    offset_y = (new_height - img.height) // 2
    result.paste(img, (offset_x, offset_y))

    if 'bytes' in response_format:
        format = "JPEG"
        # 创建一个字节流缓冲区
        buffered = io.BytesIO()
        # 将图像保存到缓冲区
        result.save(buffered, format)
        # 获取缓冲区的字节内容
        img_bytes = buffered.getvalue()

        return img_bytes

    elif 'base64' in response_format:
        format = "JPEG"
        # 创建一个字节流缓冲区
        buffered = io.BytesIO()
        # 将图像保存到缓冲区
        result.save(buffered, format)
        # 获取缓冲区的字节内容
        img_bytes = buffered.getvalue()
        # 将字节内容编码为Base64字符串
        img_base64 = base64.b64encode(img_bytes).decode("utf-8")
        return f"data:image/{format.lower()};base64,{img_base64}"

    elif response_format == 'url':
        format = "JPEG"
        # 创建一个字节流缓冲区
        buffered = io.BytesIO()
        # 将图像保存到缓冲区
        result.save(buffered, format)
        # 获取缓冲区的字节内容
        img_bytes = buffered.getvalue()

        return await to_url(img_bytes, f"{shortuuid.random()}.jpg")

    else:
        result.save(response_format)
        print(f"✅ {image} -> {response_format}")
        print(f"   原尺寸: {img.width}x{img.height} (比例: {img_ratio:.2f})")
        print(f"   新尺寸: {new_width}x{new_height} (比例: {target_ratio:.2f})")
        return result


if __name__ == '__main__':
    # import tempfile
    #
    # # 使用上下文管理器自动处理文件的关闭和删除
    # with tempfile.NamedTemporaryFile(mode='wb+') as temp:
    #     temp.write(b"This is a temporary file.")
    #     temp.seek(0)
    #     print(f"文件内容: {temp.read()}")
    #     print(f"临时文件名: {temp.name}")
    # 文件在这里自动关闭和删除

    # arun(to_bytes(''))

    # arun(to_url("x.png"))

    # url = "https://storage.googleapis.com/bsp-remini-image-in-web-us-central1-autodelete/54a2d77f-3070-4a95-8a1b-906ac1c74d44/64439c90-c628-47e0-9e1b-36dbbbd06664/ba502f58/input.jpg?X-Goog-Algorithm=GOOG4-HMAC-SHA256&X-Goog-Credential=GOOG1ETQDJI557KBP4YD5TQG6FMZHVKCP3S53FHI6XLBYYMT24W3PZAZNZZWQ%2F20241014%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20241014T060335Z&X-Goog-Expires=3600&X-Goog-SignedHeaders=host&X-Goog-Signature=b7745e3639a1cb81465409bfa7ed20801c5b997945739810c32cb4af02304893"

    # arun(to_base64(url))[:100]

    url = "https://oss.ffire.cc/files/kling_watermark.png"

    # arun(to_file(url, filename='x.jpg'))

    file = Path("/Users/betterme/PycharmProjects/AI/MeUtils/meutils/io/x.py").read_bytes()

    # arun(to_url_fal([file] * 1))

    # print(mimetypes.guess_type("http://url"))
    # print(mimetypes.guess_type("http://url.pdf"))
    # print(mimetypes.guess_type("http://url.php"))
    #
    # print(mimetypes.guess_type("xx.txt"))
    # print(mimetypes.guess_type("xx.html"))
    # print(mimetypes.guess_type("xx.mp3"))
    # print(mimetypes.guess_type("xx.mp4"))

    # print(guess_mime_type("http://url")) # application # msword

    # arun(to_bytes(None))

    # print(mimetypes.guess_type("x.jpg"))
    # print(mimetypes.guess_type("x.png"))
    # print(mimetypes.guess_type("x.jpg"))

    # print(mimetypes.guess_extension("x.mp4", False))

    # arun(to_url(
    #     "https://cdn.hailuoai.video/moss/prod/2024-11-11-09/video/1731287464150180347-video_raw_8ba15c5c206f8d393a9248f4f9215ed8_312186282087260162.mp4",
    #     content_type=None))

    # arun(to_url_fal(url))
    # print(guess_mime_type(b"base64xxxxxxxxxxxxxxxxxx.mp4"))

    # arun(to_url([Path('img_1.png').read_bytes()], filename='x.png'))
    file = "/Users/betterme/PycharmProjects/AI/ppt.txt"
    arun(to_url(Path(file).read_bytes(), filename='ppt.txt'))

    # arun(markdown_base64_to_url("![image](data:imagexxxxx)", pattern=r'!\[image\]\((.+?)\)'))

    # arun(to_bytes("https://oss.ffire.cc/files/kling_watermark.png"))

    # file = "https://v3.fal.media/files/penguin/Rx-8V0MVgkVZM6PJ0RiPD_douyin.mp4"
    # arun(to_bytes(file))

    # print(guess_mime_type("http://admin.ilovechatgpt.top/file/ceshiwendangdocx_31118702.docx "))

    url = "https://juzhen-1318772386.cos.ap-guangzhou.myqcloud.com/mj/2025/06/07/7b347a36-8146-4d3d-a5dc-0b8dc365817d.png"
    # r = arun(to_bytes(url))

    print(mimetypes.guess_type(url)[0])

    # url = "https://lmdbk.com/5.mp4"
    # url = "https://v3.fal.media/files/kangaroo/y5-1YTGpun17eSeggZMzX_video-1733468228.mp4"
    # content = requests.get(url).content
    #
    # url = "https://fal.media/files/koala/8teUPbRRMtAUTORDvqy0l.mp4"
    #
    # with timer():
    #     # arun(get_file_duration(content=content))
    #     arun(get_file_duration(url=url))

    # r = arun(to_url([]))
    # text = "这是一个示例文本，包含一个图片：![image](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABAAAAAQACAIAAADwf7zUAAAgAElEQ) 这张图片很棒。"
    #
    # arun(markdown_base64_to_url(
    #     text=text,
    #     # pattern=r'!\[.*?\]\((data:image/.*?)\)'
    #     # pattern=r'!\[.*?\]\((.*?)\)'
    #
    # )
    # )

    # webp_bytes = Path("/Users/betterme/PycharmProjects/AI/MeUtils/meutils/apis/images/image1.webp").read_bytes()
    # webp_bytes = Path("image_0.emf",).read_bytes()
    #
    # arun(to_png(webp_bytes, response_format='b64'))

    # url = "https://r2.syntx.ai/user_5317909153/uploaded/5a8b8eaabe4d56957053cb5dee790abf_photo_2025-09-17_17-03-07_1758152505.jpg"
    # url = "https://mjimg.zhanjuzhe.cn/raw/banana_media/202509/17/20250917110929784771.JPG".lower()
    # arun(to_png(url, response_format='b64'))

    # guess_mime_type('xx.jpg')

    # arun(to_base64('a'))
    url = "https://lmdbk.com/5.mp4"
    url = "https://v15-kling.klingai.com/bs2/upload-ylab-stunt-sgp/minimax_tts/05622a13394bc31ce681ada011462007/audio.mp3"
    # arun(get_file_duration(filename='.mp4', url=url))

    # arun(do_file_data([None]))

    image = ["https://v3.fal.media/files/penguin/XoW0qavfF-ahg-jX4BMyL_image.webp"] * 2

    image = "https://v3.fal.media/files/penguin/XoW0qavfF-ahg-jX4BMyL_image.webp"

    image = "https://kimi-web-img.moonshot.cn/img/www.vhv.rs/50fef4f80227d1d7d2ae212599fc4a3d2fa91c81.png"

    image = "https://cdnzjzai.m.nengshuohuihua.com/banana/refer/202602/02/20260202152544761374.jpeg?auth_key=1770017144-86e367a61b7a46a7894a1072dfe8a539-0-060089b876fb3c713bdafcfbb16ac844"
    # print(guess_mime_type(image))
    # arun(to_image(image))

    # arun(to_url(image, content_type="image/jpeg"))

    url = "https://ark-common-storage-prod-cn-beijing.tos-cn-beijing.volces.com/doubao-seedance-2-0/2104716667/0/20260212/02177089914238900000000000000000000ffffac183fc8d5d6cf.mp4%3FX-Tos-Algorithm=TOS4-HMAC-SHA256&X-Tos-Credential=AKLTYWJkZTExNjA1ZDUyNDc3YzhjNTM5OGIyNjBhNDcyOTQ%252F20260212%252Fcn-beijing%252Ftos%252Frequest&X-Tos-Date=20260212T123107Z&X-Tos-Expires=86400&X-Tos-Signature=065ea666a698224b237f7c0be0e31cc01a9ff7bd99caf0f90b1123095cf23cd4&X-Tos-SignedHeaders=host?X-Tos-Algorithm=TOS4-HMAC-SHA256&X-Tos-Credential=AKLTMjgxMzUwNzliYzdlNDE4MTllYjJjZGVlOWQ3N2M1ZDY%2F20260212%2Fcn-beijing%2Ftos%2Frequest&X-Tos-Date=20260212T135308Z&X-Tos-Expires=604800&X-Tos-Signature=b982ef2fb2b2acffe10192a0412781ee57b3fdaa26af6fccbbe8cb40022dd22f&X-Tos-SignedHeaders=host"

    arun(to_url(url, content_type="video/mp4"))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : utils
# @Time         : 2024/12/18 11:03
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *
import random
import base64
import time
import uuid
import secrets
import string

# 常量定义
MODEL_NAME = "doubao"
DEFAULT_ASSISTANT_ID = "497858"
VERSION_CODE = "20800"
DEVICE_ID = random.random() * 999999999999999999 + 7000000000000000000
WEB_ID = random.random() * 999999999999999999 + 7000000000000000000
USER_ID = str(uuid.uuid4()).replace('-', '')
MAX_RETRY_COUNT = 3
RETRY_DELAY = 5000
FILE_MAX_SIZE = 100 * 1024 * 1024

# 伪装headers
FAKE_HEADERS = {
    "Accept": "*/*",
    "Accept-Encoding": "gzip, deflate, br, zstd",
    "Accept-language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
    "Cache-control": "no-cache",
    "Last-event-id": "undefined",
    "Origin": "https://www.doubao.com",
    "Pragma": "no-cache",
    "Priority": "u=1, i",
    "Referer": "https://www.doubao.com",
    "Sec-Ch-Ua": '"Google Chrome";v="131", "Chromium";v="131", "Not_A Brand";v="24"',
    "Sec-Ch-Ua-Mobile": "?0",
    "Sec-Ch-Ua-Platform": '"Windows"',
    "Sec-Fetch-Dest": "empty",
    "Sec-Fetch-Mode": "cors",
    "Sec-Fetch-Site": "same-origin",
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36"
}


async def acquire_token(refresh_token: str) -> str:
    """
    获取缓存中的access_token
    目前doubao的access_token是固定的，暂无刷新功能

    Args:
        refresh_token: 用于刷新access_token的refresh_token

    Returns:
        str: access_token
    """
    return refresh_token


def generate_fake_ms_token() -> str:
    """
    生成伪msToken
    """
    # 生成96字节的随机数据
    random_bytes = secrets.token_bytes(96)
    # 转换为base64，并替换特殊字符
    token = base64.b64encode(random_bytes).decode('utf-8')
    return token.replace('+', '-').replace('/', '_').rstrip('=')


def generate_random_string(length: int) -> str:
    """
    生成指定长度的随机字符串
    """
    chars = string.ascii_letters + string.digits
    return ''.join(random.choice(chars) for _ in range(length))


def generate_fake_a_bogus() -> str:
    """
    生成伪a_bogus
    """
    return f"mf-{generate_random_string(34)}-{generate_random_string(6)}"


def generate_params():
    params = {
        "aid": "497858",
        "device_id": int(DEVICE_ID),
        "device_platform": "web",
        "language": "zh",
        "pkg_type": "release_version",
        "real_aid": "497858",
        "region": "CN",
        "samantha_web": "1",
        "sys_region": "CN",
        "tea_uuid": int(WEB_ID),
        "use-olympus-account": "1",
        "version_code": "20800",
        "web_id": int(WEB_ID),
        "msToken": generate_fake_ms_token(),
        "a_bogus": generate_fake_a_bogus()
    }

    return params


def generate_jimeng_params():
    params = {
        "aid": "513695",
        "device_platform": "web",
        "region": "cn",
        "webId": int(WEB_ID),
        "da_version": "3.3.9",
        "os": "mac",
        "web_component_open_flag": "1",
        "web_version": "7.5.0",
        "aigc_features": "app_lip_sync",
        "msToken": generate_fake_ms_token(),
        "a_bogus": generate_fake_a_bogus()
    }

    return params


def generate_cookie(refresh_token: str, ms_token: Optional[str] = None) -> str:
    """
    生成cookie
    """
    ms_token = ms_token or generate_fake_ms_token()

    current_timestamp = int(time.time())
    cookie_parts = [
        f"is_staff_user=false",
        f"store-region=cn-gd",
        f"store-region-src=uid",
        f"sid_guard={refresh_token}%7C{current_timestamp}%7C5184000%7CSun%2C+02-Feb-2025+04%3A17%3A20+GMT",
        f"uid_tt={USER_ID}",
        f"uid_tt_ss={USER_ID}",
        f"sid_tt={refresh_token}",
        f"sessionid={refresh_token}",
        f"sessionid_ss={refresh_token}",
        f"msToken={ms_token}",
    ]
    return "; ".join(cookie_parts)


async def get_upload_token(refresh_token):  # 3600过期
    """

    {'code': 0,
     'data': {'auth': {'access_key_id': 'AKTPYzNkMjJlNTNjMWE1NDJiN2E5MWFkOTYxMWViYzQxYTM',
                       'current_time': '2024-12-18T11:17:22+08:00',
                       'expired_time': '2024-12-18T12:17:22+08:00',
                       'secret_access_key': 'HFFTkEFKf+0DVpUrYy2yMzvgnkxLMU6+qydnGUSaDmd0vSRedpIi0qmeWSVElyOU',
                       'session_token': 'STS2eyJMVEFjY2Vzc0tleUlkIjoiQUtMVFlUZGhPR0ptWVRNNFl6ZG1OR1JoWVRoaE0yWTJPVFl5TW1SbU0yRmhNREEiLCJBY2Nlc3NLZXlJZCI6IkFLVFBZek5rTWpKbE5UTmpNV0UxTkRKaU4yRTVNV0ZrT1RZeE1XVmlZelF4WVRNIiwiU2lnbmVkU2VjcmV0QWNjZXNzS2V5IjoiTC9WZTVSMmt4N3dsY1kvS0E5alp1WVlpSlVFM0ZjdHMzQ2Q5QjJZMVE3NlRnUDVONWViMmpKQkRQMUdyUEtqeXNYNXRKVkJPdExvVjVNOGFyY24wQ2ZtdUZRRWMxMG8xMSs3UHdKdGY0LzQ9IiwiRXhwaXJlZFRpbWUiOjE3MzQ0OTU0NDIsIlBvbGljeVN0cmluZyI6IntcIlN0YXRlbWVudFwiOlt7XCJFZmZlY3RcIjpcIkFsbG93XCIsXCJBY3Rpb25cIjpbXCJJbWFnZVg6QXBwbHlJbWFnZVVwbG9hZFwiLFwiSW1hZ2VYOkNvbW1pdEltYWdlVXBsb2FkXCJdLFwiUmVzb3VyY2VcIjpbXCJ0cm46SW1hZ2VYOio6KjpTZXJ2aWNlSWQvYTlybnMycmw5OFwiXX0se1wiRWZmZWN0XCI6XCJBbGxvd1wiLFwiQWN0aW9uXCI6W1wiUFNNXCJdLFwiUmVzb3VyY2VcIjpbXCJmbG93LmFsaWNlLnJlc291cmNlX2FwaVwiXX1dfSIsIlNpZ25hdHVyZSI6ImI2MGUxNDZkZTU0Njg2NTdlYzVlZmFjZjJlOWNlOWE5YTdhY2UwNTFlZTdkYTJjZTRmNjdiYmRiM2U4MDQ3N2IifQ=='},
              'service_id': 'a9rns2rl98',
              'upload_host': 'imagex.bytedanceapi.com',
              'upload_path_prefix': 'bot-chat-image'},
     'msg': ''}

    :return:
    """
    cookie = generate_cookie(refresh_token)
    url = "https://www.doubao.com/alice/upload/auth_token"

    headers = {
        'Cookie': cookie,
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36"
    }
    payload = {
        "scene": "bot_chat",
        "data_type": "image"
    }

    async with httpx.AsyncClient(timeout=60) as client:
        response = await client.post(url, headers=headers, json=payload)
        response.raise_for_status()

        return response.json()


if __name__ == '__main__':
    # generate_cookie("")

    arun(get_upload_token("712a47e7eec7c03b4cc7229775e06841"))
    # print(generate_params())
    # print(get_signing_key('xW9YbDhTlWsXdaN7O2g1lfcyePxf5kJyg/r2mwSZG/iuSmbvVgToO6LVCLmUjVJ3'))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : wechat
# @Time         : 2021/5/26 3:50 下午
# @Author       : yuanjie
# @WeChat       : 313303303
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
import wechatsogou

# 可配置参数

# 直连
ws_api = wechatsogou.WechatSogouAPI()


ws_api.search_gzh('南京航空航天大学') | xlist | xprint




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2024/10/21 20:17
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://platform.minimaxi.com/document/video_generation?key=66d1439376e52fcee2853049
# https://useapi.net/docs/start-here/setup-minimax
# token 过期时间一个月: 看下free hailuo
# https://jwt.io/
# todoc 重试 内容生成失败。请重试。


from meutils.pipe import *
from meutils.io.files_utils import to_bytes, to_image
from meutils.io.image import image_resize

from meutils.schemas.hailuo_types import BASE_URL_ABROAD as BASE_URL

from meutils.decorators.retry import retrying
from meutils.notice.feishu import send_message as _send_message, VIDEOS

from meutils.apis.hailuoai.yy import get_yy
from meutils.apis.hailuoai.utils import PARAMS as params, get_access_token, upload
from meutils.apis.hailuoai import openai_images

from meutils.schemas.video_types import SoraVideoRequest, Video
from meutils.schemas.image_types import ImageRequest

send_message = partial(
    _send_message,
    title=__name__,
    url=VIDEOS
)

APP_ID = '3001'
VERSION_CODE = '22203'

MODEL_MAPPING = {
    # video-01 video-01 video-01-live2d S2V-01

    "t2v-01": "23000",  # 23010
    "t2v-01-director": "23010",

    "i2v-01": "23001",
    "i2v-01-live": "23011",
    "video-01-live2d": "23011",
    "s2v-01": "23021",

    # "23210" # 要积分
}


class Tasks(object):

    def __init__(self, base_url: Optional[str] = None, api_key: str = None):
        self.api_key = api_key

    async def create(self, request: SoraVideoRequest):
        if request.model.replace("async/", "").startswith(("image", "nano", "seedream", "gpt-image")):
            image_request = ImageRequest(
                model=request.model,
                prompt=request.prompt,
                size=request.size,
                aspect_ratio=request.aspect_ratio,
                resolution=request.resolution,
                image=request.input_reference,
            )
            logger.debug(image_request)
            return await openai_images.generate(image_request, api_key=self.api_key, is_async=True)
        else:
            return await create_task(request, self.api_key)

    async def get(self, task_id: str):
        logger.debug(task_id)

        return await get_task(task_id, self.api_key)


# @retrying(predicate=lambda r: r.base_resp.status_code in {1000061, 1500009})  # 限流
async def create_task(request: SoraVideoRequest, token: Optional[str] = None):
    refresh_token = token or os.getenv("HAILUOAI_API_KEY")
    token = await get_access_token(refresh_token)

    if request.model.startswith("veo"):
        request.seconds = 8

        if request.aspect_ratio not in {"16:9", "9:16"}:
            request.aspect_ratio = "16:9"

        if image_urls := request.input_reference:
            request.input_reference = await to_image(image_urls)

    elif request.model.startswith("sora"):
        request.seconds = int(request.seconds or 4)
        if request.seconds not in {4, 8, 12}:
            request.seconds = 4
            # request.seconds = min({4, 8, 12}, key=lambda x: x - request.seconds)

        if request.model in {"sora-2-4s", "sora-2-8s", "sora-2-12s"}:  # sora2-i2v 逆向按次
            request.seconds = request.model.rsplit('-', 1)[-1].strip("s")
            request.model = "sora2-i2v"

        request.size = request.size or "1280x720"  # todo 缩放16x9报错
        w, h = map(int, request.size.split('x'))
        request.aspect_ratio = "16:9" if w > h else "9:16"

        if image_urls := request.input_reference:
            logger.debug(f"request.size: {request.size}")

            _ = await to_image(image_urls[0], response_format="bytes")
            _ = await image_resize(_, request.size, "fal-url")
            request.input_reference = [_]

    if image_urls := request.input_reference or list(
            filter(None, [request.first_frame_image, request.last_frame_image])
    ):
        request.model = request.model.replace('t2v', 'i2v')

        if request.model.startswith('232'):  # 2.x 首帧 首尾帧   文生统一 23204
            if request.last_frame_image or len(image_urls) == 2:
                request.model = "23210"  # 首尾帧 2.0
                request.input_reference = await to_image(image_urls)


            elif request.first_frame_image or len(image_urls) == 1:

                request.model = "23218"  # 首帧 2.3-fast
                request.input_reference = await to_image(image_urls)

        elif request.model.startswith('230'):  # 1.0 文生 23000
            request.seconds = 6
            if image_urls:
                request.model = "23001"

    else:
        request.model = request.model.replace('i2v', 't2v')

    payload = {
        "quantity": 1,
        "parameter": {
            "modelID": request.model,
            "desc": request.prompt,
            "fileList": [],
            "useOriginPrompt": False if request.enhance_prompt else True,
            "duration": int(request.seconds or 4),
            "resolution": (request.resolution or "720").rstrip('p').rstrip('P'),
            "aspectRatio": ""
        },
        # "videoExtra": {
        #     "promptStruct": "{\"value\":[{\"type\":\"paragraph\",\"children\":[{\"text\":\"a cat\"}]}],\"length\":5,\"plainLength\":5,\"rawLength\":5}"
        # }
    }

    if request.aspect_ratio:
        payload['parameter']['aspectRatio'] = request.aspect_ratio

    # 图片比例过小，请上传1280x720或720x1280以上规格图片 todo
    if images := request.input_reference:  # todo 处理 file

        payload['parameter']['fileList'] = [
            {
                "frameType": i,
                "url": url,
                # "type": "jpeg",
            }
            for i, url in enumerate(images)
        ]
    if not payload['parameter']['fileList']:  # 互斥
        if url := request.first_frame_image:
            url = await to_image(url)

            payload['parameter']['fileList'] += [{"url": url, "frameType": 0}]

        if url := request.last_frame_image:
            url = await to_image(url)

            payload['parameter']['fileList'] += [{"url": url, "frameType": 1}]

    logger.debug(bjson(payload))

    path = "/v2/api/multimodal/generate/video"

    headers = {
        'Content-Type': 'application/json',
        'token': token,
        'yy': get_yy(payload, params, path),
    }

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post(path, params=params, content=json.dumps(payload))
        response.raise_for_status()

        data = response.json()

        logger.debug(bjson(data))

        if task_id := data.get("data", {}).get("id"):
            return Video(id=task_id, status=data)
        else:
            return Video(status='failed', error=data.get("statusInfo"))


async def get_task(task_id: str, token: str):
    payload = {
        "batchInfoList": [
            {
                "batchID": task_id,
                "batchType": 0  # video
            },
            {
                "batchID": task_id,
                "batchType": 1  # image
            }
        ],
        "type": 1
    }

    # {"batchInfoList": [{"batchID": "472359176514654211", "batchType": 0}], "type": 1}

    path = "/v4/api/multimodal/video/processing"
    headers = {
        'Content-Type': 'application/json',
        'token': token,
        'yy': get_yy(payload, params, url=path),
    }

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=60) as client:
        response = await client.post(path, params=params, content=json.dumps(payload)
                                     )
        response.raise_for_status()
        data = response.json()

        logger.debug(bjson(data))

        # if any(i in str(data) for i in {"内容生成失败", "请求异常"}):
        #     raise Exception(f"invalid image: {task_id} \n\n {request.prompt[:1000]}")

        if batchs := data['data']['batchVideos']:
            for batch in batchs:
                if batch["batchID"] == task_id:
                    _ = batch["assets"][0]
                    logger.debug(bjson(_))

                    # 1: "Processing",
                    # 2: "Success",
                    error = None
                    status = "queued"

                    if _.get("status") == 12:
                        status = "queued"
                    elif _.get("status") == 1:
                        status = "in_progress"
                    elif _.get("status") == 2:
                        status = "completed"
                    elif _.get("status") in {3, 5, 7, 14}:  # 失败枚举值
                        status = "failed"
                        error = {"code": _.get("status"), "message": f"""{_.get("message", "")}\n{_.get("desc")}"""}

                    video = Video(
                        id=task_id,
                        video_url=_.get("downloadURL"),

                        progress=min(_.get("percent", 11), 99),

                        created_at=_.get("createTime"),

                        status=status,
                        error=error,
                        # metadata=error and _ or None

                        metadata={"prompt": _.get("desc")}
                    )

                    if video.video_url:
                        video.progress = 100

                    return video
        return Video(id=task_id)


if __name__ == '__main__':
    token = None
    token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NzMyMTk4NjgsInVzZXIiOnsiaWQiOiI0Njk5MzQ0NTU0NDM1Mjk3MzAiLCJuYW1lIjoiYWNpbyBrcmhmIiwiYXZhdGFyIjoiIiwiZGV2aWNlSUQiOiI0NzM1NjkxMDc2MDEzNzExMzciLCJpc0Fub255bW91cyI6ZmFsc2V9fQ.qdNC8N4bvuoTB9gYT6_QEiNG5KvvssPY1t3Q3ZKKQZg"

    model = "veo3.1-t2v-fast"
    model = "23000"
    # model = "23218"
    #
    model = "veo3.1-i2v-fast_1080p"
    # model = "veo3.1-i2v-fast_3840"
    # model = "sora2-i2v"

    model = "sora-2-4s"

    # 23010
    # 472553170574090241

    MODEL_MAPPING = {
        # video-01 video-01 video-01-live2d S2V-01

        "t2v-01": "23000",  # 23010
        "i2v-01": "23001",

        "01-director": "23102",
        "01-live": "23011",

        "s2v-01": "23021",

        # 23200 # 2.0 文生
        # 23210 # 2.0

        # 23204 # 2.3 文生
        # 23217 # 2.3

        # 23218 # 2.3-fast
    }

    request = SoraVideoRequest(
        # model="t2v-01",
        model=model,
        # model="S2V-01-live",
        seconds=61,

        # prompt="smile",  # 307145017365086216
        # prompt="把小黄鸭放在衣服上",  # 307145017365086216
        # prompt="一个裸体少女",  # 307145017365086216
        prompt="A whimsical flying elephant soaring over a vibrant candy-colored cityscape at sunset, with rainbow trails behind its wings, playful monkeys riding on its back throwing confetti, in a whimsical animated style like a Pixar movie, camera panning smoothly from ground level to aerial view",
        # 307145017365086216

        # enhance_prompt=True,

        # input_reference="https://cdn.hailuoai.video/moss/prod/2026-01-26-18/user/multi_chat_file/8ac50491-63ec-46fc-9f98-94d287552003.jpeg"

        input_reference=["https://s3.ffire.cc/tmp/x.jpg"] * 1,
        # first_frame_image="https://s3.ffire.cc/files/jimeng.jpg",
        # last_frame_image="https://cdn.hailuoai.video/moss/prod/2026-01-26-18/user/multi_chat_file/8ac50491-63ec-46fc-9f98-94d287552003.jpeg",

        # first_frame_image="https://v3.fal.media/files/penguin/XoW0qavfF-ahg-jX4BMyL_image.webp",
        # last_frame_image="https://v3.fal.media/files/tiger/bml6YA7DWJXOigadvxk75_image.webp",

        # resolution="768P"

        # size="16:9"
        # size="720x1280"
        size="9x16"
    )

    # data = {
    #     "model": "veo3.1-t2v-fast",
    #     "prompt": "[Cảnh 1: Sếp bước vào văn phòng, tay cầm một phong bì màu trắng, ánh mắt đầy bí ẩn.]\n[Cảnh 2: Anh chàng mũm mĩm ngồi ở bàn làm việc, mắt dõi theo sếp, lòng đầy hồi hộp. Anh thì thầm với đồng nghiệp bên cạnh:]\n\"Không biết năm nay có đổi đời không...\"\n[Cảnh 3: Sếp đứng trước mặt anh, trao phong bì với nụ cười bí ẩn. Anh chàng mở phong bì, ánh mắt sáng lên khi thấy bên trong là một voucher giảm giá mua chuột máy tính.]\n[Cảnh 4: Anh chàng giơ voucher lên cao, nụ cười hiện rõ trên khuôn mặt với hai lúm đồng tiền đáng yêu. Anh quay sang đồng nghiệp, hài hước nói:]",
    #     "seconds": 8,
    #     # "size": "720p",
    #     # "aspect_ratio": "16:9",
    #     "resolution": "1080",
    #     # "enhance_prompt": True
    # }

    # data = {
    #     "model": "23218",
    #     "prompt": "https://cos.imyaigc.com/video/hailuo/9a550058-bb0b-4fb0-9c91-2a3d12574cd7.png 脱掉外衣外裤坐下低头含情脉脉看着镜头",
    #     "seconds": "10",
    #     "input_reference": [
    #         "https://cos.imyaigc.com/video/hailuo/9a550058-bb0b-4fb0-9c91-2a3d12574cd7.png"
    #     ],
    #     "duration": 10,
    #     "resolution": "768p"
    # }

    # request = SoraVideoRequest(**data)

    # "图片上传失败，长宽比需在 5:2 和 2:5 之间"

    data = {'model': '23204_768p',
            'prompt': '5-second time-lapse transformation. The futuristic city rapidly decays and ages into ruins. Neon lights flicker and die, buildings crumble and collapse, green vines and moss grow aggressively covering the structures. The atmosphere shifts from a cold neon night to a dusty yellow twilight. High motion, cinematic time-lapse style.',
            'seconds': '6',
            'first_frame_image': 'https://cos.imyai.top/video/hailuo/344db92e-6772-4a53-a2b4-97918045b4f7.png',
            'last_frame_image': 'https://cos.imyai.top/video/hailuo/4006137c-2ba8-4a64-99e7-c30644dc8179.png'}
    request = SoraVideoRequest(**data)

    r = arun(create_task(request, token=token))

    # task_id = "hailuoai-469852272096808964"

    # {"quantity": 1, "parameter": {"modelID": "sora2-i2v", "desc": "笑起来啊", "fileList": [{"id": "469914687591321600",
    #                                                                                         "url": "https://cdn.hailuoai.video/moss/prod/2026-01-20-15/user/multi_chat_file/997398be-fe17-4af1-ac9f-7057a54e5587.jpeg?x-oss-process=image/resize,p_50/format,webp",
    #                                                                                         "name": "cropped_1768892531810.jpeg",
    #                                                                                         "type": "jpeg",
    #                                                                                         "frameType": 0}],
    #                               "useOriginPrompt": true, "resolution": "720", "duration": 4, "aspectRatio": "16:9"},
    #  "videoExtra": {
    #      "promptStruct": "{\"value\":[{\"type\":\"paragraph\",\"children\":[{\"text\":\"笑起来啊\"}]}],\"length\":4,\"plainLength\":4,\"rawLength\":4}"}}

    # data = {
    #     "model": "video-01",
    #     "prompt": "画面中两个人非常缓慢地拥抱在一起",
    #     "prompt_optimizer": True,
    #     # "first_frame_image": "https://hg-face-domestic-hz.oss-cn-hangzhou.aliyuncs.com/avatarapp/ai-cache/54883340-954c-11ef-8920-db8e7bfa3fdf.jpeg"
    # }

    # task_id = "472543767246442500"
    # task_id = "472553541371510788"
    # task_id = "472555135056019456"
    # 472564985043406853

    # task_id = "472565145953669122"
    #
    # task_id = "472565145957863429"
    #
    # "data": {
    #     "id": "472567022007164928",
    #     "task": {
    #         "batchID": "472567022002970627",
    #         "videoIDs": [
    #             "472567022007164928"
    #         ]
    #     },
    #     "isFirstGenerate": false,

    task_id = "472578691764686853"
    task_id = "472578758479253512"
    task_id = "472581277544718343"
    task_id = "474208609112264706"
    # arun(get_task(task_id=task_id, token=token))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : re_utils
# @Time         : 2022/5/12 下午2:03
# @Author       : yuanjie
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import json
import mimetypes
import re

from meutils.pipe import *
from urllib.parse import unquote, unquote_plus

zh = re.compile('[a-zA-Z\u4e00-\u9fa5]+')  # 中文 + 字母
nozh = re.compile('[^a-zA-Z\u4e00-\u9fa5]+')  # 中文 + 字母

HTML_PARSER = re.compile(r'```html(.*?)```', re.DOTALL)


# re.sub(r'=(.+)', r'=123','s=xxxxx')

@lru_cache()
def has_chinese(text):
    pattern = re.compile(r'[\u4e00-\u9fff]')  # 基本汉字 Unicode 范围
    return bool(pattern.search(text))


@lru_cache()
def remove_date_suffix(filename):
    """
    # 测试示例
    filenames = [
        "claude-3-5-haiku-20241022",
        "o1-mini-2024-09-12",
        "gpt-3.5-turbo-0125"
    ]

    # 输出结果
    for fname in filenames:
        print(remove_date_suffix(fname))
    :param filename:
    :return:
    """
    # 匹配日期格式（YYYYMMDD 或 YYYY-MM-DD）
    pattern = r'(-\d{8}|-\d{4}-\d{2}-\d{2}|-\d+)$'
    # 使用正则表达式替换日期后缀
    return re.sub(pattern, '', filename)


def get_parse_and_index(text, pattern):
    """
    text = 'The quick brown cat jumps over the lazy dog'
    get_parse_and_index(text, r'cat')
    """
    # 编译正则表达式模式
    regex = re.compile(pattern)

    # 使用re.finditer匹配文本并返回匹配对象迭代器
    matches = regex.finditer(text)

    # 遍历匹配对象迭代器，输出匹配项及其在文本中的位置
    for match in matches:  # 大数据
        yield match.start(), match.end(), match.group()


@lru_cache()
def parse_url(text: str, for_image=False, fn: Optional[Callable] = None):
    if text.strip().startswith("http") and len(re.findall("http", text)) == 1:  # http开头且是单链接
        return text.split(maxsplit=1)[:1]

    fn = fn or (lambda x: x.removesuffix(")"))

    # url_pattern = r'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\\(\\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
    url_pattern = r'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+|#]|[!*\\(\\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+'

    # url_pattern = r"((https?|ftp|www\\.)?:\\/\\/)?([a-zA-Z0-9.-]+\\.[a-zA-Z]{2,})(:[0-9]+)?(\\/[^\\s]*)?"

    if for_image:
        text = unquote_plus(text)
        # suffix = [
        #     ".jpg",
        #     ".jpeg",
        #     ".png",
        #     ".gif",
        #     ".bmp",
        #     ".tiff",
        #     ".psd",
        #     ".ai",
        #     ".svg",
        #     ".webp",
        #     ".ico",
        #     ".raw",
        #     ".dng"
        # ]
        # url_pattern = r'https?://[\w\-\.]+/\S+\.(?:png|jpg|jpeg|gif)'
        url_pattern = r'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[#]|[!*\\(\\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+\.(?:jpg|jpeg|png|gif|svg|webp)'

        # "https://i.miji.bid/2025/06/10/d018000aed9b872c7b248dccf14c4450.pngA" 纠正

    urls = re.findall(url_pattern, text)

    valid_urls = []
    for url in urls:
        url = fn(url.strip(r"\n"))

        valid_urls.append(url)

    return valid_urls


def parse_url_from_json():
    pass


def parse_command_string(command_str: str) -> dict: # parse cmd
    """
    解析一个类似 "prompt --key1 value1 --key2 value2" 格式的字符串。

    Args:
        command_str: 输入的命令行字符串。

    Returns:
        一个包含 prompt 和解析后参数的字典。
        例如: {"prompt": "画条狗", "size": "1:1", "n": 10}
    """
    # 初始化结果字典
    result = {}

    # 使用正则表达式找到第一个参数 '--' 的位置
    # 这比简单的 split 更健壮，可以处理 prompt 中包含 '--' 的情况（虽然不常见）
    match = re.search(r'\s--\w', command_str)

    if not match:
        # 如果没有找到任何参数，整个字符串都是 prompt
        result['prompt'] = command_str.strip()
        return result

    first_arg_index = match.start()

    # 提取 prompt 和参数部分
    prompt = command_str[:first_arg_index].strip()
    args_str = command_str[first_arg_index:].strip()

    result['prompt'] = prompt

    # 将参数字符串按空格分割成列表
    # 例如 "--size 1:1 --n 10" -> ['--size', '1:1', '--n', '10']
    args_list = args_str.split()

    # 遍历参数列表，每次处理一个键值对
    i = 0
    while i < len(args_list):
        arg = args_list[i]

        # 确认当前项是一个参数键（以 '--' 开头）
        if arg.startswith('--'):
            key = arg[2:]  # 去掉 '--' 前缀

            # 检查后面是否跟着一个值
            if i + 1 < len(args_list) and not args_list[i + 1].startswith('--'):
                value = args_list[i + 1]

                # 尝试将值转换为整数，如果失败则保留为字符串
                try:
                    processed_value = int(value)
                except ValueError:
                    processed_value = value

                # 布尔型
                if processed_value in ['true', 'yes', 'on']:
                    processed_value = True
                elif processed_value in ['false', 'no', 'off']:
                    processed_value = False

                result[key] = processed_value

                i += 2  # 跳过键和值，移动到下一个参数
            else:
                # 处理没有值的参数，例如 --test，可以设为 True 或忽略
                result[key] = True  # 或者可以写 pass 直接忽略
                i += 1
        else:
            # 如果某一项不是以 '--' 开头，它可能是格式错误，直接跳过
            i += 1

    return result


def parse_base64(text, pattern=r'!\[.*?\]\((.*?)\)'):
    """
    :param text:
    :param pattern:
        pattern=r'!\[.*?\]\((data:image/.*?)\)'
    :return:
    """
    base64_strings = re.findall(pattern, text)
    return base64_strings


if __name__ == '__main__':
    # from urllib.parse import urlparse
    #
    #
    # def is_valid_url(url):
    #     try:
    #         result = urlparse(url)
    #         return all([result.scheme, result.netloc])
    #     except:
    #         return False

    text = """7个正规url
    这是一段包含URL的文本，https://www.google.com 是一个URL，另一个URL是http://www.baidu.com
    解读这个文本https://www.url1.com
    https://www.url2.com 解读这个文本
    http://www.url2.com 解读这个文本

    https://www.url2.com解读这个文本

    总结 waptianqi.2345.com/wea_history/58238.html

    总结 https://waptianqi.2345.com/wea_history/58238.htm
    解释下这张照片 https://img-home.csdnimg.cn/images/20201124032511.png
        解释下这张https://img-home.csdnimg.cn/images/x.png

        img-home.csdnimg.cn/images/20201124032511.png


    https://oss.ffire.cc/files/百炼系列手机产品介绍.docx
    
    https://mj101-1317487292.cos.ap-shanghai.myqcloud.com/ai/test.pdf\n\n文档里说了什么？

    
        https://oss.ffire.cc/files/%E6%8B%9B%E6%A0%87%E6%96%87%E4%BB%B6%E5%A4%87%E6%A1%88%E8%A1%A8%EF%BC%88%E7%AC%AC%E4%BA%8C%E6%AC%A1%EF%BC%89.pdf 这个文件讲了什么？

    """

    # https://oss.ffire.cc/files/%E6%8B%9B%E6%A0%87%E6%96%87%E4%BB%B6%E5%A4%87%E6%A1%88%E8%A1%A8%EF%BC%88%E7%AC%AC%E4%BA%8C%E6%AC%A1%EF%BC%89.pdf 正则匹配会卡死
    # from urllib3.util import parse_url
    # text = "@firebot /换衣 https://oss.ffire.cc/files/try-on.png"
    # text = "@firebot /换衣 https://oss.ffire.cc/files/try-on.pn"

    # print(parse_url(text))
    # print(parse_url(text, for_image=True))
    print(parse_url(text, for_image=False))

    d = {"url": "https://mj101-1317487292.cos.ap-shanghai.myqcloud.com/ai/test.pdf\n\n总结下"}
    # print(parse_url(str(d)))

    text = "https://sc-maas.oss-cn-shanghai.aliyuncs.com/outputs/bb305b60-d258-4542-8b07-5ced549e9896_0.png?OSSAccessKeyId=LTAI5tQnPSzwAnR8NmMzoQq4&Expires=1739948468&Signature=NAswPSXj4AGghDuoNX5rVFIidcs%3D 笑起来"

    print(parse_url(text))

    # print(parse_url("[](https://oss.ffire.cc/cdn/2025-03-20/YbHhMbrXV82XGn4msunAJw)"))

    # print('https://mj101-1317487292.cos.ap-shanghai.myqcloud.com/ai/test.pdf\\n\\n'.strip(r"\n"))

    # print(parse_url("http://154.3.0.117:39666/docs#/default/get_content_preview_spider_playwright_get"))

    # print(parse_url(text, True))
    text = """
https://p26-bot-workflow-sign.byteimg.com/tos-cn-i-mdko3gqilj/f13171faeed2447b8b9c301ba912f25c.jpg~tplv-mdko3gqilj-image.image?rk3s=81d4c505&x-expires=1779880356&x-signature=AJop4%2FM8VjCUfjqiEzUugprc0CI%3D&x-wf-file_name=B0DCGKG71N.MAIN.jpg

还有这种url，两个.jpg的也能兼容么

https://i.miji.bid/2025/06/10/d018000aed9b872c7b248dccf14c4450.pngA
    """
    print(parse_url(text, for_image=True))

    # print(parse_url(text, for_image=False))

    # text = """https://photog.art/api/oss/R2yh8N Convert this portrait into a straight-on,front-facing ID-style headshot."""
    # print(parse_url(text))
    #
    # valid_urls = parse_url(text, for_image=True)

    print(mimetypes.guess_type("xx.ico"))

    text = "这是一个示例文本，包含一个图片：![image](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABAAAAAQACAIAAADwf7zUAAAgAElEQ) 这张图片很棒。"
    # text = "这是一个示例文本，。"

    # print(parse_base64(text * 2))

    print(parse_command_string("画条狗 --size 1:1 --n 10"))
